import * as React from "react";
import Menu from "@mui/material/Menu";
import MenuItem from "@mui/material/MenuItem";
import { ThemeProvider, createTheme } from "@mui/material/styles";

type IOption = {
	label: string;
	value: string;
};

type IMyMenuProps = {
	children: React.ReactNode;
	options: Array<IOption>;
	value: string;
};

const theme = createTheme({
	components: {
		// Name of the component
		MuiMenuItem: {
			styleOverrides: {
				// Name of the slot
				root: {
					fontSize: "12px",
					":hover": {
						color: "red",
					},
					"&.Mui-selected": {
						backgroundColor: "#2a68c9",
					},
				},
			},
		},
	},
});

const MyMenu = (props: IMyMenuProps) => {
	const { children, options, value } = props;
	const [anchorEl, setAnchorEl] = React.useState<null | HTMLElement>(null);
	const open = Boolean(anchorEl);
	const handleClick = (event: React.MouseEvent<HTMLDivElement>) => {
		setAnchorEl(event.currentTarget);
	};
	const handleClose = (value: string) => {
		setAnchorEl(null);
		console.log(value);
	};

	return (
		<ThemeProvider theme={theme}>
			<div>
				<div onClick={handleClick}>{children}</div>
				<Menu
					id="basic-menu"
					anchorEl={anchorEl}
					open={open}
					onClose={handleClose}
					MenuListProps={{
						"aria-labelledby": "basic-button",
					}}
				>
					{options.map((option, index) => {
						return (
							<MenuItem
								onClick={() => handleClose(option.value)}
								selected={value === option.value}
								key={index}
							>
								{option.label}
								{value}
							</MenuItem>
						);
					})}
				</Menu>
			</div>
		</ThemeProvider>
	);
};

export default MyMenu;
